@@ -7,6 +7,7 @@ from sqlalchemy.sql import func
 import pandas as pd
 import numpy as np
 from ...util.singleton import Singleton
+from ...constant import FOFStrategyTypeDic
 from ..wrapper.mysql import BasicDatabaseConnector
 from ..view.basic_models import *
 from .raw import RawDataApi
@@ -252,15 +253,18 @@ class BasicDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'Failed to get data <err_msg> {e} from {FundNav.__tablename__}')
 
-    def delete_fund_nav(self, start_date, end_date):
+    def delete_fund_nav(self, start_date, end_date, fund_list: Tuple[str]):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
-                db_session.query(
+                query = db_session.query(
                     FundNav
                 ).filter(
                     FundNav.datetime >= start_date,
                     FundNav.datetime <= end_date,
-                ).delete(synchronize_session=False)
+                )
+                if fund_list:
+                    query = query.filter(FundNav.fund_id.in_(fund_list))
+                query.delete(synchronize_session=False)
                 db_session.commit()
                 return True
             except Exception as e:
@@ -1154,7 +1158,9 @@ class BasicDataApi(metaclass=Singleton):
                     query = query.filter(
                         FOFInfo.fof_id.in_(fof_id_list),
                     )
-                return pd.read_sql(query.statement, query.session.bind)
+                df = pd.read_sql(query.statement, query.session.bind)
+                df.strategy_type = df.strategy_type.map(lambda x:FOFStrategyTypeDic[x] )
+                return df
             except Exception as e:
                 print(f'failed to get_fof_info_nav_exsited <err_msg> {e} from {FOFInfo.__tablename__}')
 
