@@ -734,6 +734,60 @@ class DerivedDataApi(metaclass=Singleton):
             except Exception as e:
                 print(f'failed to get_fof_nav_public <err_msg> {e} from {FOFNavPublic.__tablename__}')
 
+    def get_fof_nav_public_adj(self, fof_id_list:Tuple[str], start_date:str='', end_date:str=''):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FOFNavPublic,
+                )
+                if fof_id_list:
+                    query = query.filter(
+                        FOFNavPublic.fof_id.in_(fof_id_list),
+                    )
+                if start_date:
+                    query = query.filter(
+                        FOFNavPublic.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        FOFNavPublic.datetime <= end_date,
+                    )
+                df = pd.read_sql(query.statement, query.session.bind)
+                dic = {
+                    'fof_id':'fund_id',
+                    'datetime':'datetime',
+                    'adjusted_nav':'nav',
+                }
+                df = df[list(dic.keys())].rename(columns=dic)
+                return df
+            except Exception as e:
+                print(f'failed to get_fof_nav_public_adj <err_msg> {e} from {FOFNavPublic.__tablename__}')
+
+    def get_fof_nav_public_adj_dt(self, start_date:str='', end_date:str=''):
+        with DerivedDatabaseConnector().managed_session() as session:
+            try:
+                query = session.query(
+                    FOFNavPublic,
+                )
+                if start_date:
+                    query = query.filter(
+                        FOFNavPublic.datetime >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        FOFNavPublic.datetime <= end_date,
+                    )
+                df = pd.read_sql(query.statement, query.session.bind)
+                dic = {
+                    'fof_id':'fund_id',
+                    'datetime':'datetime',
+                    'adjusted_nav':'nav',
+                }
+                df = df[list(dic.keys())].rename(columns=dic)
+                return df
+            except Exception as e:
+                print(f'failed to get_fof_nav_public_adj_dt <err_msg> {e} from {FOFNavPublic.__tablename__}')
+
     def delete_fof_nav_public(self, fof_id_to_delete: str, datetime_list: Tuple[str]):
         with DerivedDatabaseConnector().managed_session() as session:
             try:
@@ -1035,40 +1089,40 @@ class DerivedDataApi(metaclass=Singleton):
     def get_industry_stock_ret_and_size(self, begin_date, end_date, time_para):
         try:
             def process_x(x):
-                x.loc[:,'weight'] = x.total_share / x.total_share.sum()
-                x = x[x.weight >= 0.015]
+                x.loc[:,'weight'] = x['size'] / x['size'].sum()
+                x = x[x.weight >= 0.03]
                 return x
-            # 建议只用短时间，上时间慢
+            # load data
+            today = datetime.date.today()
+            _b_d = today - datetime.timedelta(days=90)
             raw_api = RawDataApi()
             basic_api = BasicDataApi()
             begin_date, end_date = raw_api.get_date_range(time_para, begin_date, end_date)
             stock_df = raw_api.get_em_stock_info()
-            today = datetime.date.today()
-            _b_d = today - datetime.timedelta(days=90)
+            industry_df = raw_api.get_em_industry_info()
             stock_df = stock_df[stock_df.list_date < _b_d]
+            stock_list = stock_df.stock_id.to_list()
+            total_share = raw_api.get_em_daily_info_last_date(stock_list=stock_list,columns=['total_share'])
+            stock_price = raw_api.get_em_stock_price(start_date=begin_date, end_date=end_date,stock_list=stock_list,columns=['close'])
+
+            # data_clean
+            industry_dic_name = industry_df.set_index('em_id').to_dict()['ind_name']
             stock_df = stock_df[['stock_id','name','bl_sws_ind_code']].dropna()
             stock_df.loc[:,'industry_1'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[0])
             stock_df.loc[:,'industry_2'] = stock_df.bl_sws_ind_code.map(lambda x: x.split('-')[1])
             stock_df = stock_df.drop(columns=['bl_sws_ind_code']).set_index('stock_id')
-            industry_df = raw_api.get_em_industry_info()
-            industry_dic_name = industry_df.set_index('em_id').to_dict()['ind_name']
             stock_df.loc[:,'industry_1_name'] = stock_df.industry_1.map(industry_dic_name)
             stock_df.loc[:,'industry_2_name'] = stock_df.industry_2.map(industry_dic_name)
-            stock_list = stock_df.index.tolist()
-            # TODO
-            total_share = raw_api.get_em_daily_info_last_date(stock_list=stock_list,columns=['total_share'])
             total_share = total_share.pivot_table(index='stock_id',columns='datetime',values='total_share')
             total_share.columns = ['total_share']
-            groupby_df = stock_df.join(total_share).copy()
-            stock_df = groupby_df.groupby('industry_2').apply(lambda x: process_x(x))
-            stock_df = stock_df.drop(columns=['industry_2']).reset_index().set_index('stock_id')
-            stock_list = stock_df.index.tolist()
-            stock_price = raw_api.get_em_stock_price(start_date=begin_date, end_date=end_date,stock_list=stock_list,columns=['close'])
             last_date = sorted(stock_price.datetime.unique().tolist())[-1]
             last_price = stock_price[stock_price['datetime'] == last_date]
             size_df = last_price.set_index('stock_id')[['close']].join(total_share).dropna()
             size_df.loc[:,'size'] = size_df.close*size_df.total_share
-            stock_df = stock_df.join(size_df[['size']]).dropna()
+            stock_df = stock_df.join(size_df).copy()
+            stock_df = stock_df.groupby('industry_2').apply(lambda x: process_x(x))
+            stock_df = stock_df.drop(columns=['industry_2']).reset_index().set_index('stock_id')
+
             indus_size_1 = stock_df[['industry_1','size']].groupby('industry_1').sum()
             indus_size_2 = stock_df[['industry_2','size']].groupby('industry_2').sum()
             stock_price = stock_price.pivot_table(index='datetime',columns='stock_id',values='close').ffill()
