@@ -168,6 +168,9 @@ class PortfolioDataApi(metaclass=Singleton):
             
             if not mutual_fund_nav.empty:
                 mutual_fund_nav = mutual_fund_nav.pivot_table(index='datetime',columns='fund_id',values='adjusted_net_value')
+                dts = BasicDataApi().get_trading_day_list(start_date=mutual_fund_nav.index[0]).datetime
+                mutual_fund_nav = mutual_fund_nav.reindex(mutual_fund_nav.index.intersection(dts)).ffill()
+
             if not hedge_fund_nav.empty:
                 hedge_fund_nav = hedge_fund_nav.pivot_table(index='datetime',columns='fund_id',values='nav')
             df_list = [i for i in [mutual_fund_nav, hedge_fund_nav] if not i.empty ]
@@ -366,8 +369,8 @@ class PortfolioDataApi(metaclass=Singleton):
                     'stats':[],
                 }
                 return data
-            def print_st(mdd):
-                return str(round(mdd * 100,2)) + '%' 
+            def print_st(num):
+                return round(num,4) 
             fund_nav = fund_nav.dropna()
             fund_nav.columns=['组合']
             basic = BasicDataApi()
@@ -406,6 +409,21 @@ class PortfolioDataApi(metaclass=Singleton):
             st3 = f'最大回撤恢复 {mdd1} {mdd1_d1} : {mdd1_d2}, {mdd1_lens} days'
             st4 = f'第二回撤恢复 {mdd2} {mdd2_d1} : {mdd2_d2}, {mdd2_lens} days'
             
+            stats_dic = {
+                '年化收益':ar,
+                '年化波动':av,
+                '夏普比率':sharpe,
+                '最近回撤':r_mdd,
+                '最近回撤开始':r_mdd_b1,
+                '最大回撤':mdd1,
+                '最大回撤开始时间':mdd1_d1,
+                '最大回撤结束时间':mdd1_d2,
+                '最大回撤持续时间':mdd1_lens,
+                '第二回撤':mdd2,
+                '第二回撤开始时间':mdd2_d1,
+                '第二回撤结束时间':mdd2_d2,
+                '第二回撤持续时间':mdd2_lens,
+            }
             mdd_dic_1 = {
                 'd1':str(mdd_details['mdd1_d1']),
                 'd2':str(mdd_details['mdd1_d2']),
@@ -421,7 +439,8 @@ class PortfolioDataApi(metaclass=Singleton):
             data = {
                     'data':df,
                     'mdd_1':mdd_dic_1,
-                    'stats': [st1, st2, st3]
+                    'stats': [st1, st2, st3],
+                    'stats_details':stats_dic,
                 }
             if mdd_dic_2['d1'] != 'None':
                 data['mdd_2'] = mdd_dic_2
@@ -434,6 +453,7 @@ class PortfolioDataApi(metaclass=Singleton):
             data = {
                 'data':df,
                 'stats':[],
+                'stats_details':{},
             }
             return data
 
@@ -1003,7 +1023,8 @@ class PortfolioDataApi(metaclass=Singleton):
             bps = str(int((port_nav['data']['组合'].values[-1] / port_nav['data']['组合'].values[0] - 1) * 10000)) +'BP'
             res_1 = port_nav['stats'][0]
             result_1_str = f'{res_1} 总收益 {bps}'
-
+            result_1_str_dic = {k: v for k, v in port_nav['stats_details'].items() if k in ['年化收益','年化波动','夏普比率']}
+            result_1_str_dic['总收益'] = bps
             _index_price = result['大类净值'].loc[begin_date:]
             benchmark_id_info_r = {v: k for k, v in benchmark_id_info.items()}
             index_price = self.get_index_and_asset_price(index_list=list(benchmark_id_info.values()),begin_date=fund_nav.index[0], end_date=fund_nav.index[-1])
@@ -1045,6 +1066,7 @@ class PortfolioDataApi(metaclass=Singleton):
             result_3['权重'] = result_3['权重'].map(lambda x: str(round(100*x,2))) +'%'
             dic = (result_3[['基金类型','基金收益']].groupby('基金类型').sum()*10000).astype(int).astype(str)
             result_2_str = ' '.join([f'{k} {int(v)}BP' for k, v in dic.to_dict()['基金收益'].items()])
+            result_2_dic = { k: str(int(v))+'BP' for k,v in dic.to_dict()['基金收益'].items()}
             result_3['基金收益'] = result_3['基金收益'].map(lambda x: str(int(10000*x))) +'BP'
             result_3['基金涨跌'] = result_3['基金涨跌'].map(lambda x : str(round(x * 100,2))+'%')
             result_3 = result_3[['基金名','开始时间','结束时间','基金类型','基金涨跌','权重','基金收益']]
@@ -1053,8 +1075,10 @@ class PortfolioDataApi(metaclass=Singleton):
             data = {
                 '组合收益':result_1,
                 '组合收益描述':result_1_str,
+                '组合收益细节':result_1_str_dic,
                 '资产价格比收益':result_2,
                 '资产价格比收益描述':result_2_str,
+                '资产价格比收益细节':result_2_dic,
                 '个基近期收益':result_3,
             }
             return data
@@ -1065,8 +1089,10 @@ class PortfolioDataApi(metaclass=Singleton):
             data = {
                 '组合收益':df,
                 '组合收益描述':[],
+                '组合收益细节':{},
                 '资产价格比收益':df,
                 '资产价格比收益描述':[],
+                '资产价格比收益细节':{},
                 '个基近期收益':df,
             }
             return data
@@ -1223,7 +1249,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 result.append(_df)
             if len(_asset_list_3) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_3]
-                _df = derived.get_fof_nav_public_adj(fund_ids=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
+                _df = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date=begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
             if len(_asset_list_4) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_4]
@@ -1289,7 +1315,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 result.append(_df)
             if len(_asset_list_3) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_3]
-                _df = derived.get_fof_nav_public_adj(fund_ids=real_ids,start_date=_begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
+                _df = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date=_begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
             if len(_asset_list_4) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_4]
@@ -1351,7 +1377,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 result.append(_df)
             if len(_asset_list_3) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_3]
-                _df = derived.get_fof_nav_public_adj(fund_ids=real_ids,start_date=_begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
+                _df = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date=_begin_date,end_date=end_date).pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
             if len(_asset_list_4) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_4]
@@ -1396,7 +1422,7 @@ class PortfolioDataApi(metaclass=Singleton):
             asset_info = asset_info.append(_df).drop_duplicates('real_id')
             result = []
             real_ids = product_list
-            _df = derived.get_fof_nav_public_adj(fund_ids=real_ids,start_date=begin_date,end_date=end_date)
+            _df = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date=begin_date,end_date=end_date)
             if not _df.empty > 0:
                 _df = _df.pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
@@ -1443,7 +1469,7 @@ class PortfolioDataApi(metaclass=Singleton):
                     name_dic[k] = v
             result = []
             real_ids = product_list
-            _df = derived.get_fof_nav_public_adj(fund_ids=real_ids,start_date='20091231')
+            _df = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date='20091231')
             if not _df.empty > 0:
                 _df = _df.pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
@@ -1531,7 +1557,7 @@ class PortfolioDataApi(metaclass=Singleton):
                 result.append(_df)
             if len(_asset_list_3) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_3]
-                _df = derived.get_fof_nav_public_adj(fund_ids=real_ids,start_date='20091231').pivot_table(index='datetime',columns='fund_id',values='nav')
+                _df = derived.get_fof_nav_public_adj(fof_id_list=real_ids,start_date='20091231').pivot_table(index='datetime',columns='fund_id',values='nav')
                 result.append(_df)
             if len(_asset_list_4) > 0:
                 real_ids = [asset_dic[i] for i in _asset_list_4]
@@ -1597,7 +1623,7 @@ class PortfolioDataApi(metaclass=Singleton):
             if not fund_nav.empty:
                 fund_nav = fund_nav.pivot_table(index='datetime', values='adjusted_net_value', columns='fund_id')
                 result.append(fund_nav)
-            hf_fund_nav = derived.get_fof_nav_public_adj(fund_ids=id_list, start_date=begin_date, end_date=end_date)
+            hf_fund_nav = derived.get_fof_nav_public_adj(fof_id_list=id_list, start_date=begin_date, end_date=end_date)
             if not hf_fund_nav.empty:
                 hf_fund_nav = hf_fund_nav.pivot_table(index='datetime', values='nav', columns='fund_id')
                 result.append(hf_fund_nav)
