@@ -332,7 +332,7 @@ class BasicDataPart1:
         df = df[df['fund_id'].notna()]
         self._data_helper._upload_basic(df, FundNav.__table__.name)
 
-    def fund_nav(self, start_date, end_date):
+    def fund_nav(self, start_date, end_date, fund_list: Tuple[str] = ()):
         try:
             raw_start_date_dt: datetime.date = pd.to_datetime(start_date, infer_datetime_format=True).date()
             end_date = pd.to_datetime(end_date, infer_datetime_format=True).date()
@@ -348,7 +348,7 @@ class BasicDataPart1:
             print(f'[fund_nav] (start_date){start_date} (del_date){del_date} (end_date){end_date}')
 
             # start_date = start_date.strftime('%Y%m%d')
-            df = self._raw_data_api.get_em_fund_nav(start_date, end_date).drop(columns='_update_time')
+            df = self._raw_data_api.get_em_fund_nav(start_date, end_date, fund_ids=fund_list).drop(columns='_update_time')
             df['fund_id'] = df.apply(
                 lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
             df = df.drop(['CODES'], axis=1)
@@ -361,16 +361,17 @@ class BasicDataPart1:
                     'UNITYIELD10K': 'daily_profit',
                     'YIELDOF7DAYS': 'weekly_yield'
                 })
-            df['weekly_yield'] = df['weekly_yield'].map(lambda x: x / 100.0)
+            df['weekly_yield'] = df['weekly_yield'].map(lambda x: x / 100.0 if not pd.isnull(x) else x)
 
             anv_df = df.pivot_table(index='datetime', columns='fund_id', values='adjusted_net_value').fillna(method='ffill')
             df = df.set_index(['datetime', 'fund_id'])
             df['change_rate'] = (anv_df / anv_df.shift(1) - 1).stack()
 
             df = df[df.index.get_level_values(level='datetime').date >= del_date]
+            df = df.reset_index()
             # TODO: 最好应该原子提交下边两步
-            BasicDataApi().delete_fund_nav(del_date, end_date)
-            self._data_helper._upload_basic(df.reset_index(), FundNav.__table__.name)
+            BasicDataApi().delete_fund_nav(del_date, end_date, df.fund_id.to_list())
+            self._data_helper._upload_basic(df, FundNav.__table__.name)
             return True
         except Exception as e:
             print(e)
@@ -1537,8 +1538,8 @@ class BasicDataPart1:
 
 if __name__ == '__main__':
     bdp = BasicDataPart1(BasicDataHelper())
-    # start_date = '20200428'
-    # end_date = '20200428'
+    # start_date = '20210601'
+    # end_date = '20210601'
     # bdp.fund_nav(start_date, end_date)
     # bdp.index_price(start_date, end_date)
     # bdp.rq_stock_price(start_date, end_date)
