@@ -104,6 +104,7 @@ class FundManagerFundRankProcessor:
             failed_tasks.append('manager_fund_rank')
         return failed_tasks
 
+
 if __name__ == "__main__":
-    dm = DataStore.load_dm()
-    self = FundManagerFundRank(DerivedDataHelper())
\ No newline at end of file
+    fmfr = FundManagerFundRankProcessor(DerivedDataHelper())
+    fmfr.process('20210111')
