@@ -143,6 +143,8 @@ class FundIndicatorProcessor(object):
  
     def _process_fund_indicator_update(self, fund_id, time_range, fund_ret, index_id, index_ret):
         df = fund_ret[[fund_id]].join(index_ret).dropna()
+        if df.empty:
+            return
         df = df.rename(columns={index_id:'benchmark',fund_id:'fund'}).reset_index()
         last_day = df.datetime.values[-1]
         year_length = (last_day-self.start_date_dic[fund_id]).days / self.NATURAL_DAYS_PER_YEAR
@@ -356,4 +358,4 @@ class FundIndicatorProcessor(object):
 
 if __name__ == '__main__':
     fip = FundIndicatorProcessor(DerivedDataHelper())
-    fip.process('20210201', '20210201')
+    fip.process('20210528', '20210528')
