@@ -14,11 +14,12 @@ import numpy as np
 from ...util.mail_retriever import MailAttachmentRetriever, IMAP_SPType, UID_FILE_NAME
 from ...util.wechat_bot import WechatBot
 from ...util.calculator import Calculator
+from ...constant import FOFStrategyType
 from ..wrapper.mysql import RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector
 from ..api.raw import RawDataApi
 from ..api.basic import BasicDataApi
 from ..api.derived import DerivedDataApi
-from ..view.raw_models import HFIndexPrice, HFFundNav
+from ..view.raw_models import HFIndexPrice, HFFundNav, HFFundInfo
 from ..view.basic_models import FOFInfo
 from ..view.derived_models import FOFNavPublic
 from ..fund.raw.other_raw_data_downloader import OtherRawDataDownloader
@@ -27,6 +28,18 @@ from ..fund.raw.raw_data_helper import RawDataHelper
 
 class ResearchNAVReader:
 
+    _FUND_INFO_COL_NAME: Dict[str, str] = {
+        '策略类型*': 'stg_type',
+        '产品简称*': 'desc_name',
+        '产品ID*': 'fund_id',
+        '成立日期*': 'begin_date',
+        '机构ID*': 'agency_id',
+        '机构简称': 'agency_name',
+        '基金经理': 'manager_name',
+        '来源': 'source',
+        '净值来源': 'nav_source',
+    }
+
     def __init__(self, read_dir: str, user_name: str, password: str):
         pd.set_option('display.max_rows', None)
         pd.set_option('display.max_columns', None)
@@ -193,6 +206,49 @@ class ResearchNAVReader:
         tar.close()
         return update_info
 
+    @staticmethod
+    def _read_for_FundInfo(file_path: str):
+        tar = tarfile.open(file_path, 'r:gz', encoding='gb2312')
+        for one in tar:
+            df = pd.read_excel(tar.extractfile(one), sheet_name='产品列表', header=1, na_values=['--'])
+            df = df.loc[:, df.notna().any(axis=0)].dropna(subset=['产品简称*']).drop(columns=['标签'])
+            df = df[list(ResearchNAVReader._FUND_INFO_COL_NAME.keys())].rename(columns=ResearchNAVReader._FUND_INFO_COL_NAME)
+            df['begin_date'] = df.begin_date.dt.date
+            df = df.drop_duplicates()
+            hf_fund_info = RawDataApi().get_hf_fund_info()
+            if hf_fund_info is not None:
+                to_inserted_df = df.astype(hf_fund_info.dtypes.to_dict())
+                # merge on all columns
+                to_inserted_df = to_inserted_df.merge(hf_fund_info, how='left', indicator=True, validate='one_to_one')
+                to_inserted_df = to_inserted_df[to_inserted_df._merge == 'left_only'].drop(columns=['_merge'])
+            else:
+                to_inserted_df = df
+            print(to_inserted_df)
+            if not to_inserted_df.empty:
+                to_inserted_df = to_inserted_df.replace({np.nan: None}).drop_duplicates(subset=['fund_id'])
+                # TODO: 最好原子提交下边两步
+                RawDataApi().delete_hf_fund_info(fund_id_list=to_inserted_df.fund_id.to_list())
+                # 更新到db
+                to_inserted_df.to_sql(HFFundInfo.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
+
+            existed_fof_info = BasicDataApi().get_fof_info('1', list(df.fund_id.unique()))
+            lacked_fof_ids = set(df.fund_id.array) - set(existed_fof_info.fof_id.array)
+            if lacked_fof_ids:
+                df = df[df.fund_id.isin(lacked_fof_ids)].rename(columns={
+                    'fund_id': 'fof_id',
+                    'begin_date': 'established_date',
+                    'agency_id': 'management_ids',
+                    'agency_name': 'admin',
+                    'manager_name': 'fof_manager',
+                })
+                df['strategy_type'] = df.stg_type.map(FOFStrategyType.get_type_of_names())
+                df['fof_name'] = df['desc_name']
+                df['manager_id'] = '1'
+                df = df.drop(columns=['source', 'nav_source', 'stg_type'])
+                df = df.drop_duplicates(subset='fof_id', keep='first')
+                print(df)
+                df.to_sql(FOFInfo.__table__.name, BasicDatabaseConnector().get_engine(), index=False, if_exists='append')
+
     def _notify_error_event(self, err_msg: str):
         print(f'[read_navs_and_dump_to_db] {err_msg}')
         # self._wechat_bot.send_hedge_fund_nav_update_failed(err_msg)
@@ -214,6 +270,7 @@ class ResearchNAVReader:
             self._notify_error_event(f'FATAL ERROR!! get new data of hedge fund nav failed (e){e}')
             return
 
+        rdh = RawDataHelper()
         uid_last_succeed: Optional[bytes] = None
         for name, comp_date in data.items():
             uid, file_path = comp_date
@@ -224,7 +281,7 @@ class ResearchNAVReader:
                 if '净值数据' in name:
                     update_info = ResearchNAVReader._read_for_NAVData(file_path)
 
-                    ordd = OtherRawDataDownloader(RawDataHelper())
+                    ordd = OtherRawDataDownloader(rdh)
                     ret = ordd.hf_fund_nav_miss()
                     assert not ret, 'update table of hf fund nav miss failed!!'
 
@@ -233,6 +290,14 @@ class ResearchNAVReader:
                     update_info = ResearchNAVReader._read_for_IndexData(file_path)
 
                     # self._wechat_bot.send_research_data_update('指数', update_info)
+                elif '跟踪产品' in name:
+                    ResearchNAVReader._read_for_FundInfo(file_path)
+
+                    ordd = OtherRawDataDownloader(rdh)
+                    ret = ordd.hf_fund_nav_miss()
+                    assert not ret, 'update table of hf fund nav miss failed!!'
+
+                    # self._wechat_bot.send_research_data_update('基金信息', update_info)
                 else:
                     raise NotImplementedError('unknown research nav file from attachment')
             except Exception as e:
