@@ -338,7 +338,7 @@ class FundFactorUpdater:
         return str(fac_class).split('.')[-1].split("'")[0]
 
     @staticmethod
-    def do_update_everyday() -> List[str]:
+    def do_update_every_week() -> List[str]:
         # 更新至现在
 
         def do_one_factor_update(obj) -> bool:
@@ -346,12 +346,15 @@ class FundFactorUpdater:
             if obj.name in factor_done:
                 #Factor._factor_names_set.discard(obj.name)
                 return True
-            for dep in obj._deps:
-                ret &= do_one_factor_update(dep)
+            if obj._deps != set():
+                for dep in obj._deps:
+                    ret &= do_one_factor_update(dep)
 
-            if one in append_update_factor_name:
+            if type(obj) in append_update_factor_name:
+                print(f'[append method] [{obj.name}] ')
                 ret &= obj.append_update()
             else:
+                print(f'[history method] [{obj.name}] ')
                 obj.calc()
                 ret &= obj.save()
             if ret:
@@ -364,13 +367,13 @@ class FundFactorUpdater:
             return ret
                 
         factor_list = fund_basic_factor + fund_derived_factor + fund_derived_score
-        append_update_factor_name = [fund_append_update_factor]
+        append_update_factor_name = fund_append_update_factor
         factor_done = set()
         failed_f = set()
         for one in factor_list:
             try:
-                result = do_one_factor_update(one)
-                obj_name = FundFactorUpdater.do_one_factor_update(one)
+                obj_name = FundFactorUpdater.get_class_str_name(one)
+                result = do_one_factor_update(one())
             except Exception as e:
                 print(f'update derived factor {obj_name} failed (err_msg){e}')
                 traceback.print_exc()
